import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates a query to retrieve a list of messages.
 * The `queryMessages()` function builds a query to retrieve a list of messages and returns a `MessagesQueryBuilder` object.
 * The returned object contains the query definition, which is typically used to run the query using the `find()` function.
 * You can refine the query by chaining `MessagesQueryBuilder` functions onto the query. `MessagesQueryBuilder` functions enable you to sort, filter, and control the results `queryMessages()` returns.
 * `queryMessages()` runs with these `MessagesQueryBuilder` defaults, which you can override:
 *
 * *`skip(0)`
 * * `limit(50)`
 * * `ascending("createdDate")`
 *
 * The functions that are chained to `queryMessages()` are applied in the order they are called. For example, if you apply `ascending('createdDate')` and then `descending('id')`, the results are sorted first by the created date, and then, if there are multiple results with the same created date, the messages are sorted by ID.
 *
 * ## Supported Filters and Sorting
 *
 * | Field | Supported Filters | Sortable  |
 * |----------------|------------------------------------------------------------------------------------------|-----------|
 * | `id`           | [All operators](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#operators). | Sortable  |
 * | `createdDate`  | [All operators](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#operators). | Sortable  |
 */
export declare function queryMessages(payload: object): RequestOptionsFactory<any>;
/**
 * Asks a question to the AI Assistant.
 *
 * This method creates and sends a message from a Wix user.
 */
export declare function askQuestion(payload: object): RequestOptionsFactory<any>;
/** Adds feedback to a message. */
export declare function addFeedback(payload: object): RequestOptionsFactory<any>;
/**
 * Synchronously updates tags on a list of messages, specified using the messages' IDs.
 *
 * If a tag appears in both `assignTags` and `unassignTags`, it is assigned.
 */
export declare function bulkUpdateMessageTags(payload: object): RequestOptionsFactory<any>;
/**
 * Asynchronously updates tags on a list of messages, specified by applying a filter to all messages. If a filter is not specified, this method updates all messages.
 *
 * If a tag appears in both `assignTags` and `unassignTags`, it is assigned.
 */
export declare function bulkUpdateMessageTagsByFilter(payload: object): RequestOptionsFactory<any>;
/** Updates extended fields. This method does not increment the revision. */
export declare function updateExtendedFields(payload: object): RequestOptionsFactory<any>;
