import { HttpClient } from '@wix/sdk-types';
import { AddFeedbackOptions, AddFeedbackResponse, AddFeedbackResponseNonNullableFields, AskQuestionResponse, AskQuestionResponseNonNullableFields, BulkUpdateMessageTagsByFilterOptions, BulkUpdateMessageTagsByFilterResponse, BulkUpdateMessageTagsByFilterResponseNonNullableFields, BulkUpdateMessageTagsOptions, BulkUpdateMessageTagsResponse, BulkUpdateMessageTagsResponseNonNullableFields, Message, MessagesQueryBuilder, UpdateExtendedFieldsOptions, UpdateExtendedFieldsResponse, UpdateExtendedFieldsResponseNonNullableFields } from './innovation-playground-v2-message-assistant-training.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function queryMessages(httpClient: HttpClient): QueryMessagesSignature;
interface QueryMessagesSignature {
    /**
     * Creates a query to retrieve a list of messages.
     * The `queryMessages()` function builds a query to retrieve a list of messages and returns a `MessagesQueryBuilder` object.
     * The returned object contains the query definition, which is typically used to run the query using the `find()` function.
     * You can refine the query by chaining `MessagesQueryBuilder` functions onto the query. `MessagesQueryBuilder` functions enable you to sort, filter, and control the results `queryMessages()` returns.
     * `queryMessages()` runs with these `MessagesQueryBuilder` defaults, which you can override:
     *
     * *`skip(0)`
     * * `limit(50)`
     * * `ascending("createdDate")`
     *
     * The functions that are chained to `queryMessages()` are applied in the order they are called. For example, if you apply `ascending('createdDate')` and then `descending('id')`, the results are sorted first by the created date, and then, if there are multiple results with the same created date, the messages are sorted by ID.
     *
     * ## Supported Filters and Sorting
     *
     * | Field | Supported Filters | Sortable  |
     * |----------------|------------------------------------------------------------------------------------------|-----------|
     * | `id`           | [All operators](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#operators). | Sortable  |
     * | `createdDate`  | [All operators](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#operators). | Sortable  |
     */
    (): MessagesQueryBuilder;
}
export declare function askQuestion(httpClient: HttpClient): AskQuestionSignature;
interface AskQuestionSignature {
    /**
     * Asks a question to the AI Assistant.
     *
     * This method creates and sends a message from a Wix user.
     * @param - Question message.
     */
    (question: Message): Promise<AskQuestionResponse & AskQuestionResponseNonNullableFields>;
}
export declare function addFeedback(httpClient: HttpClient): AddFeedbackSignature;
interface AddFeedbackSignature {
    /**
     * Adds feedback to a message.
     * @param - ID of the message to add feedback to.
     */
    (messageId: string, options: AddFeedbackOptions): Promise<AddFeedbackResponse & AddFeedbackResponseNonNullableFields>;
}
export declare function bulkUpdateMessageTags(httpClient: HttpClient): BulkUpdateMessageTagsSignature;
interface BulkUpdateMessageTagsSignature {
    /**
     * Synchronously updates tags on a list of messages, specified using the messages' IDs.
     *
     * If a tag appears in both `assignTags` and `unassignTags`, it is assigned.
     * @param - Message IDs. Tags are updated for messages included in this list.
     */
    (ids: string[] | null, options?: BulkUpdateMessageTagsOptions | undefined): Promise<BulkUpdateMessageTagsResponse & BulkUpdateMessageTagsResponseNonNullableFields>;
}
export declare function bulkUpdateMessageTagsByFilter(httpClient: HttpClient): BulkUpdateMessageTagsByFilterSignature;
interface BulkUpdateMessageTagsByFilterSignature {
    /**
     * Asynchronously updates tags on a list of messages, specified by applying a filter to all messages. If a filter is not specified, this method updates all messages.
     *
     * If a tag appears in both `assignTags` and `unassignTags`, it is assigned.
     * @param - Filter to apply to the messages. Tags are updated for messages included in this filter.
     */
    (filter: Record<string, any> | null, options?: BulkUpdateMessageTagsByFilterOptions | undefined): Promise<BulkUpdateMessageTagsByFilterResponse & BulkUpdateMessageTagsByFilterResponseNonNullableFields>;
}
export declare function updateExtendedFields(httpClient: HttpClient): UpdateExtendedFieldsSignature;
interface UpdateExtendedFieldsSignature {
    /**
     * Updates extended fields. This method does not increment the revision.
     * @param - ID of the entity to update.
     * @param - Identifier for the app whose extended fields are being updated.
     */
    (_id: string, namespace: string, options: UpdateExtendedFieldsOptions): Promise<UpdateExtendedFieldsResponse & UpdateExtendedFieldsResponseNonNullableFields>;
}
export { Action, ActionEvent, AddFeedbackOptions, AddFeedbackRequest, AddFeedbackResponse, AddFeedbackResponseNonNullableFields, ApplicationError, AskQuestionRequest, AskQuestionResponse, AskQuestionResponseNonNullableFields, Body, BulkActionMetadata, BulkUpdateMessageTagsByFilterOptions, BulkUpdateMessageTagsByFilterRequest, BulkUpdateMessageTagsByFilterResponse, BulkUpdateMessageTagsByFilterResponseNonNullableFields, BulkUpdateMessageTagsOptions, BulkUpdateMessageTagsRequest, BulkUpdateMessageTagsResponse, BulkUpdateMessageTagsResponseNonNullableFields, BulkUpdateMessageTagsResult, Category, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, Document, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, ExtendedFields, Feedback, FeedbackType, IdentificationData, IdentificationDataIdOneOf, ItemMetadata, Message, MessageEnvelope, MessagesQueryBuilder, MessagesQueryResult, QueryMessagesRequest, QueryMessagesResponse, QueryMessagesResponseNonNullableFields, RestoreInfo, Sender, SortOrder, Sorting, TagList, Tags, UpdateExtendedFieldsOptions, UpdateExtendedFieldsRequest, UpdateExtendedFieldsResponse, UpdateExtendedFieldsResponseNonNullableFields, WebhookIdentityType, } from './innovation-playground-v2-message-assistant-training.universal.js';
